@@ -28,7 +28,7 @@
 #define	IMKLOG_H_INCLUDED 1
 
 #include "rsyslog.h"
-#include "syslogd.h"
+#include "dirty.h"
 
 /* interface to "drivers"
  * the platform specific drivers must implement these entry points. Only one
@@ -58,6 +58,7 @@ rsRetVal imklogLogIntMsg(int priority, char *fmt, ...) __attribute__((format(pri
 rsRetVal Syslog(int priority, uchar *msg);
 
 /* prototypes */
+extern int klog_getMaxLine(void); /* work-around for klog drivers to get configured max line size */
 extern int InitKsyms(char *);
 extern void DeinitKsyms(void);
 extern int InitMsyms(void);
